@@ -1,7 +1,10 @@
+use crate::analysis::annotation::Annotation;
 use crate::clarity::analysis::ContractAnalysis;
 use crate::clarity::ast::ContractAST;
 use crate::clarity::costs::{ExecutionCost, LimitedCostTracker};
 use crate::clarity::coverage::TestCoverageReport;
+use crate::clarity::diagnostic::Diagnostic;
+use crate::clarity::types;
 use serde_json::Value;
 use std::collections::BTreeMap;
 
@@ -22,10 +25,11 @@ pub struct ExecutionResult {
         ContractAST,
         ContractAnalysis,
     )>,
-    pub result: Option<String>,
+    pub result: Option<types::Value>,
     pub events: Vec<Value>,
     pub cost: Option<CostSynthesis>,
     pub coverage: Option<TestCoverageReport>,
+    pub diagnostics: Vec<Diagnostic>,
 }
 
 #[derive(Clone, Debug)]
