@@ -1264,4 +1264,61 @@ mod tests {
             red!("Parsing error: invalid digit found in string")
         );
     }
+
+    #[test]
+    fn evaluate_at_block() {
+        let mut settings = SessionSettings::default();
+        settings.include_boot_contracts = vec!["costs-v1".into()];
+        settings.costs_version = 1;
+
+        let mut session = Session::new(settings);
+        session.start().expect("session could not start");
+
+        // setup contract state
+        session.handle_command(
+            "
+            (define-data-var x uint u0)
+
+            (define-read-only (get-x)
+                (var-get x))
+            
+            (define-public (incr)
+                (begin
+                    (var-set x (+ (var-get x) u1))
+                    (ok (var-get x))))",
+        );
+
+        // assert data-var is set to 0
+        assert_eq!(
+            session.handle_command("(contract-call? .contract-2 get-x)")[0],
+            green!("u0")
+        );
+
+        // advance chain tip and test at-block
+        session.advance_chain_tip(10000);
+        assert_eq!(
+            session.handle_command("(contract-call? .contract-2 get-x)")[0],
+            green!("u0")
+        );
+        session.handle_command("(contract-call? .contract-2 incr)");
+        assert_eq!(
+            session.handle_command("(contract-call? .contract-2 get-x)")[0],
+            green!("u1")
+        );
+        assert_eq!(session.handle_command("(at-block (unwrap-panic (get-block-info? id-header-hash u0)) (contract-call? .contract-2 get-x))")[0], green!("u0"));
+        assert_eq!(session.handle_command("(at-block (unwrap-panic (get-block-info? id-header-hash u5000)) (contract-call? .contract-2 get-x))")[0], green!("u0"));
+
+        // advance chain tip again and test at-block
+        session.advance_chain_tip(10);
+        assert_eq!(
+            session.handle_command("(contract-call? .contract-2 get-x)")[0],
+            green!("u1")
+        );
+        session.handle_command("(contract-call? .contract-2 incr)");
+        assert_eq!(
+            session.handle_command("(contract-call? .contract-2 get-x)")[0],
+            green!("u2")
+        );
+        assert_eq!(session.handle_command("(at-block (unwrap-panic (get-block-info? id-header-hash u10000)) (contract-call? .contract-2 get-x))")[0], green!("u1"));
+    }
 }
